@@ -2,7 +2,7 @@ import os
 
 import click
 
-from ..libsyscall.analyzer.scall_trace_analyzer import scall_trace_analyzer
+from SyscallAnalysis.libsyscall.analyzer.syscall_trace_constructor import SyscallTraceConstructor
 
 
 @click.command()
@@ -13,11 +13,11 @@ from ..libsyscall.analyzer.scall_trace_analyzer import scall_trace_analyzer
 def main(input_file, echo):
     cwd_path = os.path.abspath(os.path.dirname(input_file.name))
 
-    trace_analyzer = scall_trace_analyzer(cwd_path)
+    trace_cntr = SyscallTraceConstructor(cwd_path)
     strace_str = input_file.read()
 
-    trace_analyzer.parse_strace_str(strace_str)
-    for t in trace_analyzer.syscalls:
+    trace_cntr.parse_strace_str(strace_str)
+    for t in trace_cntr.syscalls:
         print(str(t))
 
 
